@@ -8,12 +8,16 @@
 # include <stdio.h>
 #endif
 
-#include <unistd.h>
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
 
 #if SIZEOF_UNSIGNED_LONG_INT == 4
  typedef unsigned long word32;
+ typedef signed long sword32;
 #elif SIZEOF_UNSIGNED_INT == 4
  typedef unsigned int word32;
+ typedef signed int sword32;
 #else
 # error "Cannot find a 32 bit integer in your system, sorry."
 #endif
