@@ -8,38 +8,42 @@ typedef struct _gaainfo gaainfo;
 
 struct _gaainfo
 {
-#line 62 "mcrypt.gaa"
+#line 68 "mcrypt.gaa"
 	char **input;
-#line 61 "mcrypt.gaa"
+#line 67 "mcrypt.gaa"
 	int size;
-#line 53 "mcrypt.gaa"
+#line 59 "mcrypt.gaa"
 	char *mode;
-#line 50 "mcrypt.gaa"
+#line 56 "mcrypt.gaa"
 	char **keys;
-#line 49 "mcrypt.gaa"
+#line 55 "mcrypt.gaa"
 	int keysize;
-#line 43 "mcrypt.gaa"
+#line 49 "mcrypt.gaa"
 	char *algorithm;
-#line 40 "mcrypt.gaa"
+#line 46 "mcrypt.gaa"
 	char *config_file;
-#line 39 "mcrypt.gaa"
+#line 45 "mcrypt.gaa"
 	int config;
-#line 36 "mcrypt.gaa"
+#line 42 "mcrypt.gaa"
 	char *keyfile;
-#line 32 "mcrypt.gaa"
+#line 38 "mcrypt.gaa"
 	int sunlink_flag;
-#line 28 "mcrypt.gaa"
+#line 34 "mcrypt.gaa"
 	int unlink_flag;
-#line 25 "mcrypt.gaa"
+#line 31 "mcrypt.gaa"
 	int bit;
-#line 22 "mcrypt.gaa"
+#line 28 "mcrypt.gaa"
 	int hexflag;
-#line 19 "mcrypt.gaa"
+#line 25 "mcrypt.gaa"
 	int ed_specified;
-#line 18 "mcrypt.gaa"
+#line 24 "mcrypt.gaa"
 	int ein;
-#line 17 "mcrypt.gaa"
+#line 23 "mcrypt.gaa"
 	int din;
+#line 20 "mcrypt.gaa"
+	int bzipflag;
+#line 17 "mcrypt.gaa"
+	int gzipflag;
 #line 13 "mcrypt.gaa"
 	int bare_flag;
 #line 10 "mcrypt.gaa"
