@@ -57,7 +57,7 @@
  int gzipflag=FALSE;
  int bzipflag=FALSE;
 #endif
- char *outfile=0;
+ char *outfile=0, *tmpc;
 
 void usage(char *name)
 {
@@ -75,7 +75,11 @@ void usage(char *name)
                               Legal parameters are:\n"));
 
    for (tmpi=0; tmpi<(MAX_ALGO+1); tmpi++) {
-    fprintf(stdout, "                              - %s\n", get_algorithms_name(tmpi));
+    tmpc=get_algorithms_name(tmpi);
+    if (tmpc!=NULL) {
+      fprintf(stdout, "                              - %s\n", tmpc);
+      free(tmpc);
+    }
    }
     fprintf(stdout, _("                              (Default is blowfish)\n"));
                               
@@ -315,106 +319,30 @@ int main(int argc,char **argv)
               if (info.mode!=NULL) {
 		modet= xmalloc(strlen(info.mode)+1);
 		strcpy(modet,info.mode);
-			if (strncasecmp(modet,"ECB",3)==0) {
-			  mode=ECB;
-			}
-	                else {
-                         if (strncasecmp(modet,"CBC",3)==0) {
-                           mode=CBC;
-			  }
-			  else {
-                            if (strncasecmp(modet,"CFB",3)==0) {
-                              mode=CFB;
-	  	            }
-	  	            else {
-                               if (strncasecmp(modet,"OFB",3)==0) {
-                                 mode=OFB;
-                               }
-	  	               else {
-                                 mode=CBC; /* Default */
-
-                              sprintf(tmperr, _("No such mode: %s\n"),modet);
-                              err_crit (tmperr);
-                              err_crit (_("Assuming CBC.\n"));
-                               }
-	  	            }
-			  }
-                        
-                        }
-			free(modet);
-                    }
+                mode=check_mode(modet);
+                if (mode==-1) {
+                   mode=CBC; /* Default */
+                   sprintf(tmperr, _("No such mode: %s\n"),modet);
+                   err_crit (tmperr);
+                   err_crit (_("Assuming CBC.\n"));
+                }
+		free(modet);
+              }
 
                     
                     if (info.algorithm!=NULL) {
                         used_algo=TRUE;
 			typet= xmalloc(strlen(info.algorithm)+1);
 			strcpy(typet,info.algorithm);
-			if (strncasecmp(typet,"DES",3)==0) {
-			  type=DES;
-			 }
-			else {
-			 if (strncasecmp(typet,"3DES",4)==0 || strncasecmp(typet,"3-DES",3)==0) {
-                          type=TripleDES;
-                         }
-                         else {
-                          if (strncasecmp(typet,"3WAY",4)==0 || strncasecmp(typet,"3-WAY",3)==0) {
-                           type=ThreeWAY;
-                          }
-                          else {
-                           if (strncasecmp(typet,"BLOWFISH",8)==0) {
+                        type=check_algo(typet);
+                        if (type==-1) {
                             type=BLOWFISH;
-                           }
-                           else {
-                             if (strncasecmp(typet,"GOST",4)==0) {
-                               type=GOST;
-                             }
-                             else {
-                              if (strncasecmp(typet,"CRYPT",5)==0) {
-                              type=CRYPT;
-                              }
-                              else {
-                                if (strncasecmp(typet,"SAFER64",7)==0 || strncasecmp(typet,"SAFER-SK64",10)==0) {
-                                  type=SAFER64;
-                                }
-                                else {
-                                  if (strncasecmp(typet,"SAFER128",8 || strncasecmp(typet,"SAFER-SK128",11)==0)==0) {
-                                    type=SAFER128;
-                                  }
-                                  else {
-                                    if (strncasecmp(typet,"CAST",4)==0) {
-                                    type=CAST128;
-                                    }
-                                    else {
-                                       if (strncasecmp(typet,"TEA",3)==0 || strncasecmp(typet,"xTEA",4)==0) {
-                                        type=TEAN;
-                                       }
-                                       else { 
-                                          if (strncasecmp(typet,"TWOFISH",7)==0) {
-                                           type=TWOFISH;
-                                          }
-                                          else {
-                                              if (strncasecmp(typet,"RC2",3)==0) {
-                                               type=RC2;
-                                              }                                          
-                                              else { /* Default */
-                                                type=BLOWFISH;
-                                                 sprintf(tmperr, _("No such algorithm: %s\n"),typet);
-                                                 err_crit (tmperr);
-                                                 err_crit (_("Assuming Blowfish.\n"));
-                                              }
-                                          }
-                                       }
-                                    }
-                                  }
-                                }
-                              }
-                             }
-                           }
-                          }
-                         }
+                            sprintf(tmperr, _("No such algorithm: %s\n"),typet);
+                            err_crit (tmperr);
+                            err_crit (_("Assuming Blowfish.\n"));
                         }
 			free(typet);
-                      } /* if */ 
+                    }
 
 
         if (info.keysize!=0 && check_env==FALSE) 
@@ -545,7 +473,7 @@ for(i=0;i<file_count;i++) {
 	    outfile= xcalloc(strlen(einfile)+5+4,1);
 	    strcpy(outfile,einfile);
             /* if file has already the .enc ignore it */
-            if (strstr( outfile, ".enc")!=NULL) {
+            if (strstr( outfile, ".enc") != NULL) {
               sprintf(tmperr, _("%s: file %s has the .enc suffix... skipping...\n"), argv[0], outfile);
               err_crit (tmperr);
               continue;
@@ -606,45 +534,33 @@ for(i=0;i<file_count;i++) {
              }
            }
 
-                      switch(mode) {
-                        case CBC:
-                        case ECB:
-                        case CFB:
-                        case OFB:
+                      if (mode<=MAX_MODE) {
+
+  			   switch (type) {
 
-  			      switch (type) {
-			        case DES:
-			        case TripleDES:
-				case ThreeWAY:
-				case BLOWFISH:
-                                case TWOFISH:
-                                case RC2:
-				case GOST:
-				case SAFER64:
-				case SAFER128:
-        	                case CAST128:
-	                        case TEAN:
-				 x=decrypt_general(type,dinfile,outfile,keyword);
-				 break;
 				case CRYPT:
 				 x=encrypt_ucrypt(dinfile,outfile,keyword);
 				 break;			 
+
                                 case NO_TYPE:
                                  x=1;
                                  break;
-                                default:
-	                         err_crit (_("Algorithm unsupported in this version\n"));
-        	                 x=1;
-                	         break;
-	                      }
-                        
 
-                          break;
-                        default:
+                                default:
+                                 if (type<=MAX_ALGO) {
+                                   x=decrypt_general(type,dinfile,outfile,keyword);
+                                 }
+                                 else {
+ 	                           err_crit (_("Algorithm unsupported in this version\n"));
+        	                   x=1;
+        	                 }
+                	         break;
+                           }
+                        }
+                        else {
                           x=1;
                           err_crit (_("Mode unsupported in this version\n"));
-                          break;
-                      }
+                        }
                       
 
 			if (x==0) {
@@ -687,44 +603,28 @@ for(i=0;i<file_count;i++) {
 
 /* Encrypt */
 	if (ein==TRUE) {
-                  switch(mode) {
-                    case CBC:
-                    case ECB:
-                    case CFB:
-                    case OFB:
-
+                if (mode<=MAX_MODE) {
 
 		      switch (type) {
-		        case DES:
-		        case TripleDES:
-	        	case ThreeWAY:
-	        	case BLOWFISH:
-                        case TWOFISH:
-                        case RC2:
-	        	case GOST:
-	        	case SAFER64:
-	        	case SAFER128:
-                        case CAST128:
-                        case TEAN:
-	        	 x=encrypt_general(type,einfile,outfile,keyword);
-	        	 break;
-	        	 
 	        	case CRYPT:
 	        	 x=encrypt_ucrypt(einfile,outfile,keyword);
 	        	 break;
 	        	 
 	        	default:
-                         err_crit (_("Algorithm unsupported in this version\n"));
-	        	 x=1;
+ 	        	 if (type<=MAX_ALGO) {
+ 	        	   x=encrypt_general(type,einfile,outfile,keyword);
+ 	        	 }
+ 	        	 else {
+                           err_crit (_("Algorithm unsupported in this version\n"));
+                           x=1;
+                         }
 	        	 break;
                         }
-                   break;
-
-                   default:
+                }
+                else {
                     x=1;
                     err_crit (_("Mode unsupported in this version\n"));
-                    break;
-                  }
+                }
 
 	        	if (x==0) {
                           if (stream_flag==FALSE) {
@@ -1698,3 +1598,46 @@ switch (mode) {
 
 }
 
+
+int check_mode(char *chain) {
+char *x, *z;
+int i;
+
+ for (i=0;i<MAX_MODE+1;i++) {
+   x=get_modes_name(i);
+   if (strlen(chain) < strlen(x)) {
+     z=chain;
+   }
+   else {
+     z=x;
+   }
+   if (strncasecmp( x, chain, strlen(z)) == 0) {
+    free(x);
+    return i;
+   }
+   free(x);
+ }
+
+return -1;
+
+}             
+
+int check_algo(char *chain) {
+int i;
+char *y;
+
+
+
+ for (i=0;i<=MAX_ALGO;i++) {
+   y=get_algorithms_name(i);
+   if (y!=NULL) {
+     if ( strncasecmp( y, chain, strlen(y)) == 0)  {
+      free(y);
+      return i;
+     }
+   free(y);
+   }
+ }
+
+return -1;
+}
