@@ -9,3 +9,7 @@ void usage(char *);
 int encrypt_general(int algorithm, char *fromfile,char *tofile,char *key);
 int decrypt_general(int algorithm, char *fromfile,char *tofile,char *key);
 
+int check_algo(char *chain); /* input is the algorithms name... output the
+                              * algorithm's number
+                              */
+int check_mode(char *chain);
